bayespy.inference.vmp.nodes.binomial.BinomialDistribution.plates_to_parent
==========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.binomial

.. automethod:: BinomialDistribution.plates_to_parent